####
SRV2 
####

*****************
Short description
*****************

The SRV2 is centrifugal compressor with an impeller and a smooth diffuser. 

For more information on the configuration and experimental data,
see: https://www.kbwiki.ercoftac.org/w/index.php/AC_6-08_Description

.. figure:: //stck/mola/data/open/mesh/SRV2/biblio/Presentation_SRV2.png
  :width: 100%
  :align: center

..   Input mesh generated with Autogrid5

***************
RANS simulation
***************

.. literalinclude:: ../../../../examples/open/workflow/rotating_component/turbomachinery/SRV2/run_sator.py
    :language: python

